Version 4.0～5.0
=================

Version4.0～5.0までのリリースノートです。

## :package: 4.1.0

:fontawesome-solid-calendar: `2023-11-05`

!!! info "Python3.11, Python3.12をサポートするようになりました"

## :package: 4.0.1

:fontawesome-solid-calendar: `2023-06-02`

!!! note "Poetryを最新化(1.1.14 -> 1.5.1)しました"

## :package: 4.0.0

:fontawesome-solid-calendar: `2022-11-16`

!!! info "Python3.10をサポートするようになりました"

!!! danger "Python3.6のサポートを終了しました"
